@@ -6,16 +6,16 @@ class Atbash:
     The Atbash Cipher
     """
 
-    def __encDec(self, alphabet, text):
-        ans = ""
+    def __crypt(self, alphabet, text):
+        res = []
         for char in text:
             try:
                 alphIndex = len(alphabet) - (alphabet.index(char)) - 1
             except ValueError:
                 wrchar = char.encode('utf-8')
                 raise Exception("Can't find char '" + wrchar + "' of text in alphabet!")
-            ans += alphabet[alphIndex]
-        return ans
+            res.append(alphabet[alphIndex])
+        return "".join(res)
 
     def encrypt(self, text, key=None, alphabet=u"abcdefghijklmnopqrstuvwxyz"):
         """
@@ -31,7 +31,7 @@ class Atbash:
         :return: text
         :rtype: string
         """
-        return self.__encDec(alphabet, text)
+        return self.__crypt(alphabet, text)
 
     def decrypt(self, text, key=None, alphabet=u"abcdefghijklmnopqrstuvwxyz"):
         """
@@ -47,4 +47,4 @@ class Atbash:
         :return: text
         :rtype: string
         """
-        return self.__encDec(alphabet, text)
+        return self.__crypt(alphabet, text)
