@@ -3,27 +3,24 @@
 
 import math
 from collections import OrderedDict
+from secretpy import alphabets as al
 
 
 class PolybiusSquare:
     """
     PolybiusSquare. It's used by many classical ciphers
     """
-    __alphabet = None
-    __side = 0
 
     def __init__(self, alphabet, key=""):
         keyi = []
         if key:
             for char in key:
-                index = self.__find_index_in_alphabet(char, alphabet)
+                index = al.get_index_in_alphabet(char, alphabet)
                 keyi.append(index)
             # remove duplicates
             keyi = OrderedDict.fromkeys(keyi)
 
-        alph_out = []
-        for i in keyi:
-            alph_out.append(alphabet[i])
+        alph_out = [alphabet[i] for i in keyi]
 
         for i in range(len(alphabet)):
             if i not in keyi:
@@ -32,15 +29,6 @@ class PolybiusSquare:
         self.__alphabet = alph_out
         self.__side = int(math.ceil(math.sqrt(len(alphabet))))
 
-    def __find_index_in_alphabet(self, char, alphabet):
-        for j in range(len(alphabet)):
-            try:
-                alphabet[j].index(char)
-                break
-            except ValueError:
-                pass
-        return j
-
     def get_coordinates(self, char):
         for j in range(len(self.__alphabet)):
             try:
@@ -49,9 +37,7 @@ class PolybiusSquare:
             except ValueError:
                 pass
 
-        row = int(j / self.__side)
-        column = j % self.__side
-        return (row, column)
+        return divmod(j, self.__side)
 
     def get_char(self, row, column):
         return self.__alphabet[row * self.__side + column][0]
@@ -60,4 +46,4 @@ class PolybiusSquare:
         return self.__side
 
     def get_rows(self):
-        return int(len(self.__alphabet) / self.__side)
+        return len(self.__alphabet) // self.__side
