@@ -7,7 +7,7 @@ from .decorator import AbstractMachineDecorator
 class LowerCase(AbstractMachineDecorator):
 
     def encrypt(self, text):
-        return self._machine.encrypt(text.lower())
+        return self._machine.encrypt(text).lower()
 
     def decrypt(self, text):
-        return self._machine.decrypt(text.lower())
+        return self._machine.decrypt(text).lower()
