@@ -7,11 +7,7 @@ from .decorator import AbstractMachineDecorator
 class UpperCase(AbstractMachineDecorator):
 
     def encrypt(self, text):
-        text = text.lower()
-        res = self._machine.encrypt(text)
-        return res.upper()
+        return self._machine.encrypt(text).upper()
 
     def decrypt(self, text):
-        text = text.lower()
-        res = self._machine.decrypt(text)
-        return res.upper()
+        return self._machine.decrypt(text).upper()
